use strict;
use warnings;
package OpusVL::AppKit::Schema::AppKitAuthDB;

use strict;
use warnings;
our $VERSION = '2';

use base 'DBIx::Class::Schema';

__PACKAGE__->load_namespaces;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

OpusVL::AppKit::Schema::AppKitAuthDB

=head1 VERSION

version 2

=head1 DESCRIPTION

=head1 NAME

OpusVL::AppKit::Schema::AppKitAuthDB - Auth Database for OpusVL::AppKit/FB11

=head1 METHODS

=head1 ATTRIBUTES

=head1 AUTHOR

Colin Newell <colin@opusvl.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by OpusVL.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
